/*  ExperimentalDesign.js
    Script for BrainVoyager QX 2.1
    June 2019: adapted for BrainVoyager 21+
    February 2024: adapted for BrainVoyager 23; please note: not backwards compatible!
*/

/* Declarations */
// var vmrname = BrainVoyager.BrowseFile("Please select the VMR file", "*.vmr"); // for all functions (*.prt, *.sdm and *.mdm creation)
//var ObjectsRawDataPath = BrainVoyager.BrowseDirectory("Please select the directory of the data") + "/";//"/Users/BVuser/Data/ObjectsDicomGSG/";
//var vtcname = BrainVoyager.BrowseFile("Please select the VTC file", "*.vtc"); // for single subject (*.prt and *.sdm)
var RFXDataPath = BrainVoyager.BrowseDirectory("Please select the directory of the random effects data") + "/";///Users/BVuser/Data/Exercise_RFX_ANOVA/";

/* This code is executed when clicking 'Run' */
// MakeProtocol();
// CreateDesignMatrix();
CreateMultiStudyDesignMatrix();

/* These functions can be invoked */
function MakeProtocol()
{
    BrainVoyager.PrintToLog("Create stimulation protocol...");
    var doc = BrainVoyager.OpenDocument( vmrname ); //ObjectsRawDataPath + "sub-01_ses-04_acq-nondistorted_T1w_IIHC_MNI.vmr" );
    doc.LinkVTC(vtcname);
    doc.ClearProtocol();//StimulationProtocol();

    doc.ProtocolExperimentName = "Faces Houses in LVF, CVF, RVF";
    doc.ProtocolResolution = 1;
    doc.AddCondition('Faces_LVF');
    doc.AddCondition('Houses_RVF');
    doc.AddCondition('Faces_CVF');
    doc.AddCondition('Houses_LVF');
    doc.AddCondition('Faces_RVF');
    doc.AddCondition('Houses_CVF');
    
    var paramWeight = 1.0; // we set here the default value

    doc.AddInterval('Faces_LVF', 4, 11, paramWeight);
    doc.AddInterval('Houses_RVF', 20, 27);
    doc.AddInterval('Faces_CVF', 36, 43);
    doc.AddInterval('Houses_LVF', 52, 59);
    doc.AddInterval('Faces_RVF', 68, 75);
    doc.AddInterval('Houses_CVF', 84, 91);
    doc.AddInterval('Faces_LVF', 100, 107);
    doc.AddInterval('Houses_RVF', 116, 123);
    doc.AddInterval('Faces_CVF', 132, 139);
    doc.AddInterval('Houses_LVF', 148, 155);
    doc.AddInterval('Faces_RVF', 164, 171);
    doc.AddInterval('Houses_CVF', 180, 187);
    doc.AddInterval('Faces_LVF', 196, 203);
    doc.AddInterval('Houses_RVF', 212, 219);
    doc.AddInterval('Faces_CVF', 228, 235);
    doc.AddInterval('Houses_LVF', 244, 251);
    doc.AddInterval('Faces_RVF', 260, 267);
    doc.AddInterval('Houses_CVF', 276, 283);
    doc.SetConditionColor('Faces_LVF', 200, 43, 43);
    doc.SetConditionColor('Houses_RVF', 200, 200, 43);
    doc.SetConditionColor('Faces_CVF', 43, 200, 43);
    doc.SetConditionColor('Houses_LVF', 43, 200, 200);
    doc.SetConditionColor('Faces_RVF', 43, 43, 200);
    doc.SetConditionColor('Houses_CVF', 200, 43, 200);
    doc.ProtocolBackgroundColorR = 0;
    doc.ProtocolBackgroundColorG = 0;
    doc.ProtocolBackgroundColorB = 0;
    doc.ProtocolTimeCourseColorR = 255;
    doc.ProtocolTimeCourseColorG = 255;
    doc.ProtocolTimeCourseColorB = 255;
    doc.ProtocolTimeCoursePenWidth = 4;

    doc.SaveProtocol(ObjectsRawDataPath + "s01_sess4_blocked_vol_script.prt");
    // MessageBox.information(String("NrOfConditions: %1".arg(doc.NrOfStimulationProtocolConditions)));

    doc.Save(); // to save link to protocol permanently
    BrainVoyager.PrintToLog("Finished creating stimulation protocol.");
}

function CreateDesignMatrix()
{
    BrainVoyager.PrintToLog("Create single subject design matrix...");
    var doc = BrainVoyager.OpenDocument(vmrname) ;
    doc.LinkVTC(vtcname);
    doc.LinkProtocol(ObjectsRawDataPath + "s01_sess4_blocked_vol_script.prt");
    doc.ClearDesignMatrix();
//    doc.AutoAddConstantPredictor();
    doc.AddPredictor('Faces_LVF');
    doc.SetPredictorValuesFromCondition('Faces_LVF', 'Faces_LVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Faces_LVF');
    doc.AddPredictor('Houses_RVF');
    doc.SetPredictorValuesFromCondition('Houses_RVF', 'Houses_RVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Houses_RVF');
    doc.AddPredictor('Faces_CVF');
    doc.SetPredictorValuesFromCondition('Faces_CVF', 'Faces_CVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Faces_CVF');
    doc.AddPredictor('Houses_LVF');
    doc.SetPredictorValuesFromCondition('Houses_LVF', 'Houses_LVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Houses_LVF');
    doc.AddPredictor('Faces_RVF');
    doc.SetPredictorValuesFromCondition('Faces_RVF', 'Faces_RVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Faces_RVF');
    doc.AddPredictor('Houses_CVF');
    doc.SetPredictorValuesFromCondition('Houses_CVF', 'Houses_CVF', 1.0);
    doc.ApplyHemodynamicResponseFunctionToPredictor('Houses_CVF');
    doc.SaveSingleStudyGLMDesignMatrix(ObjectsRawDataPath + 'FacesHousesDesignMatrix.sdm');
    BrainVoyager.PrintToLog('Saved design matrix: ' + ObjectsRawDataPath + 'FacesHousesDesignMatrix.sdm');
    // vmr.FirstConfoundPredictorOfSDM
    // run the GLM
    doc.SDMContainsConstantPredictor = 0;
    doc.CorrectForSerialCorrelations = 2; // If set to 1, AR(1) is used, if set to 2, AR(2) is used.
    doc.ComputeSingleStudyGLM();
    doc.ShowGLM();
    doc.SaveGLM(ObjectsRawDataPath + 'FacesHouses_VTC.glm');
    
    // You can also set any value at any time point (interval), here we define a linear trend predictor
/*    doc.AddPredictor("Linear Trend");
    for(i = 1; i<= doc.NrOfVolumes; i++)
    {
        value = 0.1*i;
        doc.SetPredictorValues("Linear Trend", i, i, value);
    }
    doc.ScalePredictorValues("Linear Trend", 1.0, false);
*/
//doc.AutoAddConstantPredictor(); 
    BrainVoyager.CurrentDirectory = ObjectsRawDataPath; //"/Users/BVuser/Data/ObjectsDicomGSG/");
    doc.SaveSingleStudyGLMDesignMatrix("FacesHousesDesignMatrix.sdm");
}

function CreateMultiStudyDesignMatrix()
{
    var doc = BrainVoyager.OpenDocument(RFXDataPath + "Average_Tal.vmr");
    doc.ClearMultiStudyGLMDefinition();
    var subjName;
    var nrOfSubjects = 17;
    for (i=0; i<nrOfSubjects; i++) {
        subjName = RFXDataPath + "Sub" + (i+1) + "_run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.vtc"; // create subject name
        doc.AddStudyAndDesignMatrix(subjName, RFXDataPath + "run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.sdm"); // now use subject name and always same protocol
    }
    doc.SaveMultiStudyGLMDefinitionFile(RFXDataPath + "MultiStudy_FROMSCRIPT.mdm");
    // doc.ComputeRFXGLM();

}
